Smartglass Scripts
==================

.. toctree::

   xbox.sg.scripts.client
   xbox.sg.scripts.discover
   xbox.sg.scripts.pcap
   xbox.sg.scripts.poweron
   xbox.sg.scripts.poweroff
   xbox.sg.scripts.recrypt
   xbox.sg.scripts.input
   xbox.sg.scripts.text
   xbox.sg.scripts.tui

.. automodule:: xbox.sg.scripts
    :members:
    :undoc-members:
    :show-inheritance:
